@@ -6,14 +6,15 @@ import openpyxl
 import csv
 import json
 import os
-s = Session()
-s.headers = {"User-Agent": "Google-Bot"}
 
 
 #-------------> 网络节点 <--------------
 class SessionNode(BaseNode):
-    def __init__(self, _name, _session=s):
+    def __init__(self, _name, _session=None):
         super().__init__(_name)
+        if not _session:
+            _session = Session()
+            _session.headers = {"User-Agent": "Google-Bot"}
         self._session = _session
 
 
@@ -85,6 +86,12 @@ class ParserJsonNode(BaseNode):
 
 #-------------> 组合节点 <--------------
 class ExtractNode(IterableNode):
+    def process_input(self, _input_parser):
+        for _sub_parser in _input_parser:
+            yield _sub_parser
+
+
+class SplitNode(IterableNode):
     def process_input(self, _input_parser):
         result = _input_parser.getall()
         return (i for i in result)
@@ -100,6 +107,7 @@ class ConcatNode(BaseNode):
 class PrintNode(BaseNode):
     def process_input(self, _input):
         print(colored(_input, "green"))
+        print("")
         return _input
 
 
